==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/LastQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastQuarterExpressionDescription } from "./LastQuarterExpressionDescription";
/**
 * @hidden
 */
var LastQuarterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(LastQuarterExpressionDescriptionMetadata, _super);
    function LastQuarterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LastQuarterExpressionDescriptionMetadata.b = function (a) {
        if (LastQuarterExpressionDescriptionMetadata.a == null) {
            LastQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LastQuarterExpressionDescriptionMetadata.c(LastQuarterExpressionDescriptionMetadata.a);
        }
        if (a.j(LastQuarterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(LastQuarterExpressionDescriptionMetadata.a);
    };
    LastQuarterExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    LastQuarterExpressionDescriptionMetadata.d = function (a) {
        LastQuarterExpressionDescriptionMetadata.b(a);
        a.aa("LastQuarterExpression", function () { return new LastQuarterExpressionDescription(); });
        a.z("LastQuarterExpression", LastQuarterExpressionDescriptionMetadata.a);
    };
    LastQuarterExpressionDescriptionMetadata.$t = markType(LastQuarterExpressionDescriptionMetadata, 'LastQuarterExpressionDescriptionMetadata');
    LastQuarterExpressionDescriptionMetadata.a = null;
    return LastQuarterExpressionDescriptionMetadata;
}(Base));
export { LastQuarterExpressionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/LastQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastQuarterExpressionDescription } from "./LastQuarterExpressionDescription";
/**
 * @hidden
 */
var LastQuarterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(LastQuarterExpressionDescriptionMetadata, _super);
    function LastQuarterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LastQuarterExpressionDescriptionMetadata.b = function (a) {
        if (LastQuarterExpressionDescriptionMetadata.a == null) {
            LastQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LastQuarterExpressionDescriptionMetadata.c(LastQuarterExpressionDescriptionMetadata.a);
        }
        if (a.k(LastQuarterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(LastQuarterExpressionDescriptionMetadata.a);
    };
    LastQuarterExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    LastQuarterExpressionDescriptionMetadata.d = function (a) {
        LastQuarterExpressionDescriptionMetadata.b(a);
        a.ac("LastQuarterExpression", function () { return new LastQuarterExpressionDescription(); });
        a.ab("LastQuarterExpression", LastQuarterExpressionDescriptionMetadata.a);
    };
    LastQuarterExpressionDescriptionMetadata.$t = markType(LastQuarterExpressionDescriptionMetadata, 'LastQuarterExpressionDescriptionMetadata');
    LastQuarterExpressionDescriptionMetadata.a = null;
    return LastQuarterExpressionDescriptionMetadata;
}(Base));
export { LastQuarterExpressionDescriptionMetadata };
